@@ -1,7 +1,7 @@
 package Number::Closest::NonOO;
 
 our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -160,7 +160,7 @@ Number::Closest::NonOO - Find number(s) closest to a number in a list of numbers
 
 =head1 VERSION
 
-This document describes version 0.04 of Number::Closest::NonOO (from Perl distribution Number-Closest-NonOO), released on 2015-09-03.
+This document describes version 0.05 of Number::Closest::NonOO (from Perl distribution Number-Closest-NonOO), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -176,7 +176,7 @@ This document describes version 0.04 of Number::Closest::NonOO (from Perl distri
 
 =head2 find_closest_number(%args) -> any
 
-{en_US Find number(s) closest to a number in a list of numbers}.
+{C|en_US Find number(s) closest to a number in a list of numbers}.
 
 Arguments ('*' denotes required arguments):
 
@@ -184,9 +184,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<inf> => I<str> (default: "nothing")
 
-{en_US Specify how to handle Inf}.
+{C|en_US Specify how to handle Inf}.
 
-{en_US 
+{C|en_US 
 C<exclude> means the items will first be excluded from the list. C<nothing> will
 do nothing about it and will produce a warning if target number is an infinite,
 C<number> will treat Inf like a very large number, i.e. Inf is closest to Inf and
@@ -200,24 +200,24 @@ it specifically. You should choose C<number> if target number is infinite.
 
 =item * B<items> => I<int> (default: 1)
 
-{en_US Return this number of closest numbers}.
+{C|en_US Return this number of closest numbers}.
 
 =item * B<nan> => I<str> (default: "exclude")
 
-{en_US Specify how to handle NaN and non-numbers}.
+{C|en_US Specify how to handle NaN and non-numbers}.
 
-{en_US 
+{C|en_US 
 C<exclude> means the items will first be excluded from the list. C<nothing> will
 do nothing about it, meaning there will be warnings when comparing non-numbers.
 }
 
 =item * B<number>* => I<num>
 
-{en_US The target number}.
+{C|en_US The target number}.
 
 =item * B<numbers>* => I<array>
 
-{en_US The list of numbers}.
+{C|en_US The list of numbers}.
 
 =back
 
@@ -226,7 +226,7 @@ Return value:  (any)
 
 =head2 find_farthest_number(%args) -> any
 
-{en_US Find number(s) farthest to a number in a list of numbers}.
+{C|en_US Find number(s) farthest to a number in a list of numbers}.
 
 Arguments ('*' denotes required arguments):
 
@@ -234,9 +234,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<inf> => I<str> (default: "nothing")
 
-{en_US Specify how to handle Inf}.
+{C|en_US Specify how to handle Inf}.
 
-{en_US 
+{C|en_US 
 C<exclude> means the items will first be excluded from the list. C<nothing> will
 do nothing about it and will produce a warning if target number is an infinite,
 C<number> will treat Inf like a very large number, i.e. Inf is closest to Inf and
@@ -250,24 +250,24 @@ it specifically. You should choose C<number> if target number is infinite.
 
 =item * B<items> => I<int> (default: 1)
 
-{en_US Return this number of closest numbers}.
+{C|en_US Return this number of closest numbers}.
 
 =item * B<nan> => I<str> (default: "exclude")
 
-{en_US Specify how to handle NaN and non-numbers}.
+{C|en_US Specify how to handle NaN and non-numbers}.
 
-{en_US 
+{C|en_US 
 C<exclude> means the items will first be excluded from the list. C<nothing> will
 do nothing about it, meaning there will be warnings when comparing non-numbers.
 }
 
 =item * B<number>* => I<num>
 
-{en_US The target number}.
+{C|en_US The target number}.
 
 =item * B<numbers>* => I<array>
 
-{en_US The list of numbers}.
+{C|en_US The list of numbers}.
 
 =back
 
